.. _developer_guides:

Guides for developers
==================================================

Before you start, maybe you are interested in :ref:`architecture` and :ref:`Our motivation <Our motivation of this project>` of our project.

.. toctree::
    :maxdepth: 2

    Extented Synthetic Data Generator <extension/index>
    Contributing to our project directly <contributing>
    Data Models Specification <data_models>
